<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://rextheme.com/
 * @since      1.0.0
 *
 * @package    Wpvr
 * @subpackage Wpvr/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wpvr
 * @subpackage Wpvr/public
 * @author     Rextheme <sakib@coderex.co>
 */
class Wpvr_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpvr_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpvr_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$plugin_url = plugin_dir_url( dirname(__FILE__) );
		wp_enqueue_style( $this->plugin_name . 'fontawesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all' );
		wp_enqueue_style('panellium-css', plugin_dir_url( __FILE__ ) . 'lib/pannellum/src/css/pannellum.css', array(), true);
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wpvr-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpvr_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpvr_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script('panellium-js', plugin_dir_url( __FILE__ ) . 'lib/pannellum/src/js/pannellum.js', array(), true);
		wp_enqueue_script('panelliumlib-js', plugin_dir_url( __FILE__ ) . 'lib/pannellum/src/js/libpannellum.js', array(), true);
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wpvr-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Init the edit screen of the plugin post type item
	 *
	 * @since 1.0.0
	 */
	public function public_init() {
		add_shortcode( $this->plugin_name, array( $this , 'wpvr_shortcode') );
	}

	/**
	 * Shortcode output for the plugin
	 *
	 * @since 1.0.0
	 */
	public function wpvr_shortcode( $atts ) {
		extract(
			shortcode_atts(
				array(
					'id' => 0,
					'width' => NULL,
					'height' => NULL,
					'class' => NULL
				), $atts
			)
		);

		if ( !$id ) {
			$obj = get_page_by_path( $slug, OBJECT, $this->post_type );
			if ( $obj ) {
				$id = $obj->ID;
			} else {
				return __('Invalid Wpvr slug attribute', $this->plugin_name);
			}
		}

		$postdata = get_post_meta( $id, 'panodata', true );
		$panoid = 'pano'.$id;
		$control = false;
		$control = $postdata['showControls'];
		$autoload = false;
		$autoload = $postdata['autoLoad'];
		$default_scene = '';
		$default_scene = $postdata['defaultscene'];
		$scene_fade_duration = '';
		$scene_fade_duration = $postdata['scenefadeduration'];
		$panodata = '';
		$panodata = $postdata['panodata'];

		  $default_data = array();
		  $default_data = array(__( "firstScene" )=>$default_scene,__( "sceneFadeDuration" )=>$scene_fade_duration);
		  $scene_data = array();

		  foreach ($panodata["scene-list"] as $panoscenes) {

		    $hotspot_datas = $panoscenes["hotspot-list"];
		    $hotspots = array();
		    foreach ($hotspot_datas as $hotspot_data) {

		      $hotspot_info = array(
		        __( "text" )=>$hotspot_data["hotspot-title"],
		        __( "pitch" )=>$hotspot_data["hotspot-pitch"],
		        __( "yaw" )=>$hotspot_data["hotspot-yaw"],
		        __( "type" )=>$hotspot_data["hotspot-type"],
		        __( "cssClass" )=>$hotspot_data["hotspot-customclass"],
		        __( "URL" )=>$hotspot_data["hotspot-url"],
		        __( "clickHandlerArgs" )=>$hotspot_data["hotspot-content"],
		        __( "createTooltipArgs" )=>$hotspot_data["hotspot-hover"],
		        __( "sceneId" )=>$hotspot_data["hotspot-scene"]);
		      array_push($hotspots, $hotspot_info);
		    }

		    $scene_info = array();
		    $scene_info = array(__( "type" )=>$panoscenes["scene-type"],__( "panorama" )=>$panoscenes["scene-attachment-url"],__( "hotSpots" )=>$hotspots);
		    $scene_array = array();
		    $scene_array = array(
		      __($panoscenes["scene-id"])=>$scene_info
		    );
		    $scene_data[$panoscenes["scene-id"]] = $scene_info;
		  }

		  $pano_id_array = array();
		  $pano_id_array = array(__( "panoid" )=>$panoid);
		  $pano_response = array();
		  $pano_response = array(__( "autoLoad" )=>$autoload,__( "showControls" )=>$control,__( "default" )=>$default_data,__( "scenes" )=>$scene_data);
		  $response = array();
		  $response = array($pano_id_array,$pano_response);
		  if (!empty($response)) {
			$response = json_encode($response);
		  }
		?>
		
		<div id="<?php echo 'pano'.$id; ?>" class="<?php echo 'pano-wrap'.' '.$class; ?>" style="text-align: center; width: <?php echo $width; ?>; height: <?php echo $height; ?>;">
		    <i class="fa fa-times" id="cross"></i>	
            <div id="custom-ifram" style="display: none;">
		    
		    </div>
		</div>
		<script>
		(function( $ ) {
			var response = <?php echo $response; ?>;
			var scenes = response[1];
			if (scenes) {
				$.each(scenes.scenes, function (i) {		
				    $.each(scenes.scenes[i]['hotSpots'], function (key, val) {						
				        if (val["clickHandlerArgs"] != "") {
				        	val["clickHandlerFunc"] = hotspot;
				        }
				        if (val["createTooltipArgs"] != "") {
				        	val["createTooltipFunc"] = tooltip;
				        }								 
				    });
				});
			}
			var panoshow = pannellum.viewer(response[0]["panoid"], scenes);
			function hotspot(hotSpotDiv, args) {
			    var argst = args.replace(/\\/g, '');
		    	$("#custom-ifram").html(argst);
		    	$("#custom-ifram").fadeToggle();
                 $(".pano-wrap").toggleClass("show-modal");
			}

			function tooltip(hotSpotDiv, args) {
			    hotSpotDiv.classList.add('custom-tooltip');
			    var span = document.createElement('span');
			    if (args != null) {
			        args = args.replace(/\\/g, "");  
			    }
			    span.innerHTML = args;
			    hotSpotDiv.appendChild(span);
			    // span.style.width = span.scrollWidth - 20 + 'px';
			    span.style.marginLeft = -(span.scrollWidth - hotSpotDiv.offsetWidth) / 2 + 'px';
			    span.style.marginTop = -span.scrollHeight - 12 + 'px';
			}
            
			})( jQuery );
            
            jQuery(document).ready(function($){
               $("#cross").on("click", function(e){
                   e.preventDefault();
                   $("#custom-ifram").fadeOut();
                   $(".pano-wrap").removeClass("show-modal");
                   $('iframe').attr('src', $('iframe').attr('src'));
                });
            });
		</script>
		<?php
	}

}
